.. image:: https://travis-ci.org/bnzk/djangocms-misc.svg
    :target: https://travis-ci.org/bnzk/djangocms-misc/
.. image:: https://img.shields.io/pypi/v/djangocms-misc.svg
    :target: https://pypi.python.org/pypi/djangocms-misc/
.. image:: https://img.shields.io/pypi/l/djangocms-misc.svg
    :target: https://pypi.python.org/pypi/djangocms-misc/

Development and Docs on `<https://github.com/bnzk/djangocms-misc/>`_
